summaryrefslogtreecommitdiff
path: root/src/lv2.cc
diff options
context:
space:
mode:
Diffstat (limited to 'src/lv2.cc')
-rw-r--r--src/lv2.cc22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/lv2.cc b/src/lv2.cc
index d87665d..673c650 100644
--- a/src/lv2.cc
+++ b/src/lv2.cc
@@ -8,20 +8,20 @@
****************************************************************************/
/*
- * This file is part of DrumGizmo.
+ * This file is part of CamSync.
*
* DrumGizmo is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* DrumGizmo is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with DrumGizmo; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
*/
#include <lv2/lv2plug.in/ns/lv2core/lv2.h>
@@ -35,13 +35,13 @@
#include <hugin.hpp>
-#define DRUMGIZMO_URI "http://drumgizmo.org/lv2"
-#define NS_DG DRUMGIZMO_URI "/atom#"
+#define CAMSYNC_URI "http://camsync.org/lv2"
+#define NS_DG CAMSYNC_URI "/atom#"
-// Stuff to handle DrumGizmo* transmission from instance to GUI.
-static LV2_DrumGizmo_Descriptor dg_descriptor;
+// Stuff to handle CamSync* transmission from instance to GUI.
+static LV2_CamSync_Descriptor dg_descriptor;
-static DrumGizmo *dg_get_pci(LV2_Handle instance)
+static CamSync *dg_get_pci(LV2_Handle instance)
{
DGLV2 *dglv2 = (DGLV2 *)instance;
return dglv2->dg;
@@ -142,7 +142,7 @@ LV2_Handle instantiate(const struct _LV2_Descriptor *descriptor,
dglv2->buffer = NULL;
dglv2->buffer_size = 0;
- dglv2->dg = new DrumGizmo(dglv2->out, dglv2->in);
+ dglv2->dg = new CamSync(dglv2->out, dglv2->in);
dglv2->dg->setSamplerate(sample_rate);
return (LV2_Handle)dglv2;
@@ -209,7 +209,7 @@ extern "C" {
#endif
static const LV2_Descriptor descriptor = {
- DRUMGIZMO_URI,
+ CAMSYNC_URI,
instantiate,
connect_port,
activate,
@@ -8,20 +8,20 @@
*
- * DrumGizmo is free software; you can redistribute it and/or modify
+ * CamSync is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
@@ -8,20 +8,20 @@
* (at your option) any later version.
*
- * DrumGizmo is distributed in the hope that it will be useful,
+ * CamSync is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
@@ -8,20 +8,20 @@
*
* You should have received a copy of the GNU General Public License
- * along with DrumGizmo; if not, write to the Free Software
+ * along with CamSync; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
*/